@@ -5,6 +5,7 @@ from typing import Dict, List, Union
 
 import folium
 from geopandas import GeoDataFrame
+import geopandas as gpd
 import numpy as np
 import requests
 import requests.exceptions
@@ -36,13 +37,9 @@ class Job(Tools):
     def __init__(
         self, auth: Auth, project_id: str, job_id: str, order_ids: List[str] = None,
     ):
-        """The Job class provides access to the results, parameters and tasks of UP42
+        """
+        The Job class provides access to the results, parameters and tasks of UP42
         Jobs (Workflows that have been run as Jobs).
-
-        Public Methods:
-            get_status, track_status, cancel_job, download_quicklooks, get_results_json
-            download_results, upload_results_to_bucket, map_results,
-            get_logs, get_jobtasks, get_jobtasks_results_json
         """
         self.auth = auth
         self.project_id = project_id
@@ -241,9 +238,10 @@ class Job(Tools):
 
         Args:
             show_images: Shows images if True (default), only features if False.
-            name_column: Name of the column that provides the Feature/Layer name.
-        # TODO: Make generic with scene_id column integrated.
+            name_column: Name of the feature property that provides the Feature/Layer name.
         """
+        # TODO: Make generic with scene_id column integrated.
+        # TODO: Add way to also display data block image together with processing output vectors
         if self.results is None:
             raise ValueError(
                 "You first need to download the results via job.download_results()!"
@@ -265,9 +263,15 @@ class Job(Tools):
                 "dashArray": "5, 5",
             }
 
-        # Add feature to map.
-        # TODO: Blocks that have results in separate json file.
-        df: GeoDataFrame = self.get_results_json(as_dataframe=True)  # type: ignore
+        # Add features to map.
+        # Some blocks store vector results in an additional geojson file.
+        json_fp = [fp for fp in self.results if fp.endswith(".geojson")]
+        if json_fp:
+            json_fp = json_fp[0]
+        else:
+            json_fp = [fp for fp in self.results if fp.endswith(".json")][0]
+        df: GeoDataFrame = gpd.read_file(json_fp)
+
         centroid = box(*df.total_bounds).centroid
         m = folium_base_map(lat=centroid.y, lon=centroid.x,)
 
