@@ -229,7 +229,7 @@ def _plot_images(
     ]
     if not imagepaths:
         raise ValueError(
-            f"Only files of the formats {plot_file_format} can " "currently be plotted."
+            f"This function only plots files of format {plot_file_format}."
         )
 
     if not titles:
@@ -328,6 +328,7 @@ def any_vector_to_fc(
             if df.crs.to_string() != "EPSG:4326":
                 df = df.to_crs(epsg=4326)
 
+    df.geometry = df.geometry.buffer(0)
     if as_dataframe:
         return df
     else:
